4.49. umbra.ui.visualAccelerators — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.49. umbra.ui.visualAccelerators

visualAccelerators.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application visual accelerators objects.

Others:

## 4.49.1. Module Attributes

`umbra.ui.visualAccelerators.` `LOGGER`

## 4.49.2. Functions

`umbra.ui.visualAccelerators.` `highlightCurrentLine`(editor)

  This definition highlights given editor current line.

  Parameters: | editor – Document editor. ( QWidget )
  Returns: | Method success. ( Boolean )

`umbra.ui.visualAccelerators.` `highlightOccurences`(editor)

  This definition highlights given editor current line.

  Parameters: | editor – Document editor. ( QWidget )
  Returns: | Method success. ( Boolean )

`umbra.ui.visualAccelerators.` `highlightMatchingSymbolsPairs`(editor)

  This definition highlights given editor matching pairs.

  Parameters: | editor – Document editor. ( QWidget )
  Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »